@@ -20,6 +20,21 @@ func TestNew(t *testing.T) {
 		metadata  interface{}
 		upstreams []UpstreamPackage
 	}{
+		{
+			name: "alpm package with source info",
+			syftPkg: syftPkg.Package{
+				MetadataType: syftPkg.AlpmMetadataType,
+				Metadata: syftPkg.AlpmMetadata{
+					BasePackage:  "base-pkg-info",
+					Package:      "pkg-info",
+					Version:      "version-info",
+					Architecture: "arch-info",
+					Files: []syftPkg.AlpmFileRecord{{
+						Path: "/this/path/exists",
+					}},
+				},
+			},
+		},
 		{
 			name: "dpkg with source info",
 			syftPkg: syftPkg.Package{
